jgtpy
====

JGTTechnical Indicators for the Pandas' Dataframes

Documentation: https://pandastechindicators.readthedocs.io/en/latest/

Installation
------------

::

    pip install -U jgtpy

Example
-------

::


    >>> import pandas as pd
    >>> import jgtpy 

